@@ -249,7 +249,7 @@ summary.minima<-function(object, temp=300, eunit="kJ/mol",...) {
     toprint<-cbind(toprint, exp(-1000*toprint[,tind]/8.314/temp))
   }
   if(eunit=="kcal/mol") {
-    toprint<-cbind(toprint, exp(-1000*toprint[,tind]/8.314/temp/4.184))
+    toprint<-cbind(toprint, exp(-1000*toprint[,tind]*4.184/8.314/temp))
   }
   sumpop<-sum(toprint[,tind+1])
   toprint<-cbind(toprint, 100*toprint[,tind+1]/sumpop)
@@ -530,7 +530,7 @@ summary.profiles <- function(object, imind=1, imaxd=NULL,...) {
     outprofile <- cbind(outprofile,t(mms[imaxd,]))
     names(outprofile)[5:7]<-c("min diff", "max diff", "tail")
     print(outprofile)
-  } else {
+  } else if(profs$dimension==2) {
     outprofile <- profs$mins
     mms<-profs$mms[,2:ncol(profs$mms)]-profs$mms[,2]
     outprofile <- cbind(outprofile,apply(mms[imind:imaxd,],2,min))
@@ -538,6 +538,14 @@ summary.profiles <- function(object, imind=1, imaxd=NULL,...) {
     outprofile <- cbind(outprofile,t(mms[imaxd,]))
     names(outprofile)[7:9]<-c("min diff", "max diff", "tail")
     print(outprofile)
+  } else if(profs$dimension==3) {
+    outprofile <- profs$mins
+    mms<-profs$mms[,2:ncol(profs$mms)]-profs$mms[,2]
+    outprofile <- cbind(outprofile,apply(mms[imind:imaxd,],2,min))
+    outprofile <- cbind(outprofile,apply(mms[imind:imaxd,],2,max))
+    outprofile <- cbind(outprofile,t(mms[imaxd,]))
+    names(outprofile)[9:11]<-c("min diff", "max diff", "tail")
+    print(outprofile)
   }
 }
 
